==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/mail/inc/function.mime.php <==
<?
  //$nonconvert= array("us-ascii","windows-1255","windows-1256","utf-7");

  function getfileheaderitem($filename, $item)
  {
    $result = "";

    if (!(@$file = fopen($filename, "rb"))) continue;
    while (getheaderline($file, $header, $line))
    {
      if (strtolower(trim($header)) == strtolower(trim($item)))
      {
        $result = ereg_replace("[\r\n\t]","",$line);
        break;
      }
    }
    return $result;
  }

  // changed  24.11.05
  function getheaderline($file, &$header, &$value)
  {
    while (!feof($file))
    {
      $line = fgets($file, 1024);
      if (!trim($line)) return false;
      if (!($pos = strpos($line, ":"))) continue;

      $header = trim(substr($line, 0, $pos + 1));
      $value =  rtrim(substr($line, $pos + 1));

      while (!feof($file))
      {
          $line = fgets($file, 1024);
          if ((ord($line[0]) == 9) || (ord($line[0]) == 32))
            $value .= ltrim($line);
          else {
            fseek($file, ftell($file) - strlen($line));
            break;
          }
      }

      if (strpos($value, "?=")>-1)
         $value = getheader($value);
      else//if(strpos($value, "\?Q\?"))
		 $value = charsetconvert($value,"",mycharset);

      return true;
    }

    return false;
  }

  // changed  09.11.05
  function getheader($header)
  {
    global $navka;
    $header = rtrim($header);

    $i=0;
    while(($pos = strpos($header, "=?"))>-1)
    {
      //overflow fix
      if($i>300){$header=""; break;} $i++;

      $fout .= substr($header, 0, $pos);
      $text = strstr($header, "=?");

      if(eregi("^=\?([a-z0-9\-]+)\?(Q|B)\?=",substr($text,0,30))) $strt = strpos($text,"?=")+2; else $strt = 0;


      if($endpos = strpos($text,"?=",$strt)) {
         $header = substr($text,$endpos+2);
         $text = substr($text,0,$endpos);
      }
      else
         $header = "";

      if (!eregi("^=\?([a-z0-9\-]*)\?(Q|B)\?(.*)",$text,$arr)) break;

	  $charset= $arr[1];
      $method=  $arr[2];
      $text=    $arr[3];

      if (strtoupper($method) == "Q") {
         $text = str_replace("_", " ", $text);
         $text = convertquoted($text);
      }
      elseif (strtoupper($method) == "B") $text = base64_decode($text);

      if (strcasecmp(mycharset,"us-ascii")) $text=charsetconvert($text,$charset,mycharset);

      $fout.= $text;
    }
    $fout.= $header;

	return $fout;
  }

  function convertquoted($string, $trim = true)
  {
    $converted = "";
    $i = 0;
    while (true)
    {
      if ($i >= strlen($string)) break;

      if ($string[$i] == "=")
      {
        $ch = chr(hexdec(substr($string, $i + 1, 2)));
        $converted .= ($trim ? (trim($ch)) : ($ch));
        $i += 2;
      }
      else
        { $converted .= $string[$i]; }
      $i++;
    }
    return $converted;
  }


function charsetconvert($text,$from,$to){
	global $otherconfig,$charset_settings;

	if (!$from || strtolower($from) == "us-ascii"){
		$from = split(";", $charset_settings[$otherconfig["CHARSET"]]);
		$from = $from[1];
	}

	// IMAP UTF 7
	if (strtolower($from) == "utf7-imap" || strtolower($to) == "utf7-imap"){
	
		if ($from && strtolower($from)==strtolower($to))
			return eregi_replace("\?[a-z0-9\-]*\?Q\?","",$text);

		if($text && $from && $to){
			$text2= @mb_convert_encoding($text,$to,$from);
			$text = $text2?$text2:$text;
		}

		$text = eregi_replace("\?[a-z0-9\-]*\?Q\?"," ",$text);
		return $text;
	}

	// OTHER CHARSES
	if ($to=="mycharset") $to = charset; //WAP

    if(($out = iconv($from,$to,$text)))
    	return $out;
    else
        return preg_replace('/([\xc0-\xdf].)/se','_',$text);
}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/mail/inc/function.mime.php <==
<?
  //$nonconvert= array("us-ascii","windows-1255","windows-1256","utf-7");

  function getfileheaderitem($filename, $item)
  {
    $result = "";

    if (!(@$file = fopen($filename, "rb"))) continue;
    while (getheaderline($file, $header, $line))
    {
      if (strtolower(trim($header)) == strtolower(trim($item)))
      {
        $result = ereg_replace("[\r\n\t]","",$line);
        break;
      }
    }
    return $result;
  }

  // changed  24.11.05
  function getheaderline($file, &$header, &$value)
  {
    while (!feof($file))
    {
      $line = fgets($file, 1024);
      if (!trim($line)) return false;
      if (!($pos = strpos($line, ":"))) continue;

      $header = trim(substr($line, 0, $pos + 1));
      $value =  rtrim(substr($line, $pos + 1));

      while (!feof($file))
      {
          $line = fgets($file, 1024);
          if ((ord($line[0]) == 9) || (ord($line[0]) == 32))
            $value .= ltrim($line);
          else {
            fseek($file, ftell($file) - strlen($line));
            break;
          }
      }

      if (strpos($value, "?=")>-1)
         $value = getheader($value);
      else//if(strpos($value, "\?Q\?"))
		 $value = charsetconvert($value,"",mycharset);

      return true;
    }

    return false;
  }

  // changed  09.11.05
  function getheader($header)
  {
    global $navka;
    $header = rtrim($header);

    $i=0;
    while(($pos = strpos($header, "=?"))>-1)
    {
      //overflow fix
      if($i>300){$header=""; break;} $i++;

      $fout .= substr($header, 0, $pos);
      $text = strstr($header, "=?");

      if(eregi("^=\?([a-z0-9\-]+)\?(Q|B)\?=",substr($text,0,30))) $strt = strpos($text,"?=")+2; else $strt = 0;


      if($endpos = strpos($text,"?=",$strt)) {
         $header = substr($text,$endpos+2);
         $text = substr($text,0,$endpos);
      }
      else
         $header = "";

      if (!eregi("^=\?([a-z0-9\-]*)\?(Q|B)\?(.*)",$text,$arr)) break;

	  $charset= $arr[1];
      $method=  $arr[2];
      $text=    $arr[3];

      if (strtoupper($method) == "Q") {
         $text = str_replace("_", " ", $text);
         $text = convertquoted($text);
      }
      elseif (strtoupper($method) == "B") $text = base64_decode($text);

      if (strcasecmp(mycharset,"us-ascii")) $text=charsetconvert($text,$charset,mycharset);

      $fout.= $text;
    }
    $fout.= $header;

	return $fout;
  }

  function convertquoted($string, $trim = true)
  {
    $converted = "";
    $i = 0;
    while (true)
    {
      if ($i >= strlen($string)) break;

      if ($string[$i] == "=")
      {
        $ch = chr(hexdec(substr($string, $i + 1, 2)));
        $converted .= ($trim ? (trim($ch)) : ($ch));
        $i += 2;
      }
      else
        { $converted .= $string[$i]; }
      $i++;
    }
    return $converted;
  }


function charsetconvert($text,$from,$to){
	global $otherconfig,$charset_settings;
	if (!$from)
	    $faktneni = true;
	    
	if (!$from || strtolower($from) == "us-ascii"){
		$from = split(";", $charset_settings[$otherconfig["CHARSET"]]);
		$from = $from[1];
	}

	// IMAP UTF 7
	if (strtolower($from) == "utf7-imap" || strtolower($to) == "utf7-imap"){

		if ($from && strtolower($from)==strtolower($to))
			return eregi_replace("\?[a-z0-9\-]*\?Q\?","",$text);

		if($text && $from && $to){
			$text2= @mb_convert_encoding($text,$to,$from);
			$text = $text2?$text2:$text;
		}

		$text = eregi_replace("\?[a-z0-9\-]*\?Q\?"," ",$text);
		return $text;
	}

	// OTHER CHARSES
	if ($to=="mycharset") $to = charset; //WAP

    if(($out = my_iconv($from,$to,$text)))
    	return $out;
    else
    	return preg_replace('/([\xc0-\xdf].)/se','_',$text);
}

function my_iconv($inCharset,$outCharset,$inputString)
{
	switch (strtolower($inCharset)) {
		case 'gb2312':
			$inCharset = 'gbk';
			break;
		case 'unicode':
			$inCharset = 'ucs-2le';
			break;
	}
	if(!$inCharset) {
		$inCharset = $_SESSION['DEFAULTCHARSET'];
	}
	return iconv($inCharset,$outCharset."//IGNORE",$inputString);
}

?>
